@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -229,11 +229,9 @@ QStringList PQFileFolderModel::getAllFolders(QString folder) {
         if(m_sortField != SortBy::NaturalName)
             dir.setSorting(sortFlags);
 
-        QDirIterator iter(dir);
-        while(iter.hasNext()) {
-            iter.next();
-            ret << iter.filePath();
-        }
+        const QFileInfoList lst = dir.entryInfoList();
+        for(const auto &f : lst)
+            ret << f.filePath();
 
         if(m_sortField == SortBy::NaturalName) {
             QCollator collator;
@@ -313,11 +311,9 @@ QStringList PQFileFolderModel::getAllFiles(QString folder, bool ignoreFiltersExc
                 dir.setSorting(sortFlags);
 
             if(m_nameFilters.size() == 0 && m_defaultNameFilters.size() == 0 && m_mimeTypeFilters.size() == 0 && m_imageResolutionFilter.isNull() && m_fileSizeFilter == 0) {
-                QDirIterator iter(dir);
-                while(iter.hasNext()) {
-                    iter.next();
-                    ret_cur << iter.filePath();
-                }
+                const QFileInfoList lst = dir.entryInfoList();
+                for(const auto &f: lst)
+                    ret_cur << f.filePath();
             } else {
 
                 const QFileInfoList lst = dir.entryInfoList();
@@ -480,7 +476,10 @@ void PQFileFolderModel::advancedSortMainView() {
 
         for(int i = 0; i < m_countMainView; ++i) {
 
-            if(!advancedSortKeepGoing) return;
+            if(!advancedSortKeepGoing) {
+                delete imageprovider;
+                return;
+            }
 
             // the key used for sorting
             // depending on the criteria, it is computed in different ways
@@ -523,7 +522,11 @@ void PQFileFolderModel::advancedSortMainView() {
                         tmpval += v;
                     }
                     val += static_cast<double>(tmpval)/static_cast<double>(pixelCount);
-                    if(!advancedSortKeepGoing) return;
+
+                    if(!advancedSortKeepGoing) {
+                        delete imageprovider;
+                        return;
+                    }
                 }
 
                 key = val;
@@ -555,7 +558,10 @@ void PQFileFolderModel::advancedSortMainView() {
                     }
                 }
 
-                if(!advancedSortKeepGoing) return;
+                if(!advancedSortKeepGoing) {
+                    delete imageprovider;
+                    return;
+                }
 
                 for(int i = 0 ; i < height; i++){
                     ct = (QRgb *)img.scanLine(i);
@@ -564,7 +570,10 @@ void PQFileFolderModel::advancedSortMainView() {
                     }
                 }
 
-                if(!advancedSortKeepGoing) return;
+                if(!advancedSortKeepGoing) {
+                    delete imageprovider;
+                    return;
+                }
 
                 for(int i = 0 ; i < height; i++){
                     ct = (QRgb *)img.scanLine(i);
@@ -573,7 +582,10 @@ void PQFileFolderModel::advancedSortMainView() {
                     }
                 }
 
-                if(!advancedSortKeepGoing) return;
+                if(!advancedSortKeepGoing) {
+                    delete imageprovider;
+                    return;
+                }
 
                 qint64 red_val = 0;
                 qint64 green_val = 0;
@@ -651,3 +663,17 @@ void PQFileFolderModel::advancedSortMainView() {
     });
 
 }
+
+void PQFileFolderModel::resetModel() {
+
+    delete watcherMainView;
+    watcherMainView = new QFileSystemWatcher;
+
+    delete watcherFileDialog;
+    watcherFileDialog = new QFileSystemWatcher;
+    setCountMainView(0);
+    m_entriesMainView.clear();
+
+    cache.resetData();
+
+}
