@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -49,7 +49,6 @@ public:
     void run() override;
 
     QString m_url;
-    bool m_muted;
     bool m_fixedSize;
     QSize m_requestedSize;
     QImage m_image;
@@ -61,8 +60,6 @@ private:
 
     QString whatDoIUse(QString filename);
 
-    void muteColors(QImage &img);
-
     PQLoadImage *loader;
     PQLoadImageErrorImage *load_err;
 
