@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -78,8 +78,10 @@
 int main(int argc, char **argv) {
 
 #ifdef Q_OS_WIN
-    qputenv("MAGICK_CODER_MODULE_PATH", qgetenv("PHOTOQT_MAGICK_CODER_MODULE_PATH"));
-    qputenv("MAGICK_FILTER_MODULE_PATH", qgetenv("PHOTOQT_MAGICK_FILTER_MODULE_PATH"));
+    QFileInfo f(argv[0]);
+    qputenv("PATH", QString("%1;%2").arg(qgetenv("PATH"),f.absolutePath().replace("/", "\\")).toLocal8Bit());
+    qputenv("MAGICK_CODER_MODULE_PATH", QString("%1").arg(f.absolutePath().replace("/", "\\") + "\\imagemagick\\coders").toLocal8Bit());
+    qputenv("MAGICK_FILTER_MODULE_PATH", QString("%1").arg(f.absolutePath().replace("/", "\\") + "\\imagemagick\\filters").toLocal8Bit());
 #endif
 
     // needs to be set before Q*Application is created
@@ -89,6 +91,12 @@ int main(int argc, char **argv) {
     QApplication::setAttribute(Qt::AA_UseOpenGLES);
 #endif
 
+#ifdef Q_OS_WIN
+    // On Windows Qt uses and old and long deprecated font as default
+    // This forces the app to use the same font (and size) as current Windows versions use by default
+    QGuiApplication::setFont(QFont("Segoe UI", 9));
+#endif
+
     // silence the `deprecated connection' warnings
     QLoggingCategory::setFilterRules("qt.qml.connections.warning=false");
 
@@ -101,6 +109,15 @@ int main(int argc, char **argv) {
     std::setlocale(LC_NUMERIC, "C");
 #endif
 
+#ifdef EXIV2
+    #ifdef EXIV2_ENABLE_BMFF
+        #ifdef EXV_ENABLE_BMFF
+            Exiv2::enableBMFF(true);
+        #endif
+    #endif
+#endif
+
+
     // Set app information
     QApplication::setApplicationName("PhotoQt");
     QApplication::setOrganizationName("");
