@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -69,26 +69,35 @@ void PQHandlingExternal::executeExternal(QString exe, QString args, QString curr
     QFileInfo info(currentfile);
 
     QStringList argslist;
-    QStringList argslist_tmp = args.split(" ");
 
-    for(auto &a : argslist_tmp) {
+    QStringList argslist_tmp = args.split(" ");
+    if(args.isEmpty() && exe.contains(" ")) {
+        argslist_tmp = exe.split(" ");
+        exe = argslist_tmp.takeFirst();
+    }
+
+
 #ifdef Q_OS_WIN
+    for(auto &a : argslist_tmp) {
         if(a.contains("%f"))
             a = a.replace("%f", currentfile.replace("/","\\"));
         if(args.contains("%u"))
             a = a.replace("%u", info.fileName().replace("/","\\"));
         if(a.contains("%d"))
             a = a.replace("%d", info.absolutePath().replace("/","\\"));
+        argslist << a;
+    }
 #else
+    for(auto &a : argslist_tmp) {
         if(a.contains("%f"))
             a = a.replace("%f", currentfile);
         if(args.contains("%u"))
             a = a.replace("%u", info.fileName());
         if(a.contains("%d"))
             a = a.replace("%d", info.absolutePath());
-#endif
         argslist << a;
     }
+#endif
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
 
@@ -571,7 +580,67 @@ void PQHandlingExternal::openInDefaultFileManager(QString filename) {
 #ifdef Q_OS_WIN
     QProcess::startDetached("explorer.exe", {"/select,", QDir::toNativeSeparators(filename)});
 #else
-    QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filename).absolutePath()));
+
+    // Finding out what is set as default file manager
+    QProcess proc;
+    proc.start("xdg-mime", QStringList() << "query" << "default" << "inode/directory");
+    proc.waitForFinished();
+    QString def = proc.readAllStandardOutput().toLower();
+
+    // If we find a supported file manager, store it in here
+    QString exe = "";
+    QStringList args;
+
+    // Check for all currently supported file managers
+    if(def.contains("dolphin")) {
+        exe = "dolphin";
+        args << "--select" << filename;
+    } else if(def.contains("nautilus")) {
+        exe = "nautilus";
+        args << "--select" << filename;
+    } else if(def.contains("konqbrowser")) {
+        exe = "konqueror";
+        args << "--select" << filename;
+    } else if(def.contains("thunar")) {
+        exe = "thunar";
+        args << filename;
+    } else if(def.contains("caja")) {
+        exe = "caja";
+        args << "--select" << filename;
+    } else if(def.contains("dde-file-manager")) {
+        exe = "dde-file-manager";
+        args << "--show-item" << filename;
+    } else if(def.contains("doublecmd")) {
+        exe = "doublecmd";
+        args << filename;
+    } else if(def.contains("nemo")) {
+        exe = "nemo";
+        args << filename;
+    } else if(def.contains("rox")) {
+        exe = "rox";
+        args << "-s" << filename;
+    }
+
+    // found a supported one
+    if(exe != "") {
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+
+        QProcess::startDetached(exe, args);
+
+#else
+
+        QProcess proc;
+        proc.setProgram(exe);
+        proc.setArguments(args);
+        proc.startDetached();
+
+#endif
+
+    // else open folder in default file manager
+    } else
+        QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filename).absolutePath()));
+
 #endif
 
 }
@@ -581,8 +650,6 @@ void PQHandlingExternal::saveContextMenuEntries(QVariantList entries) {
     DBG << CURDATE << "PQHandlingExternal::saveContextMenuEntries()" << NL
         << CURDATE << "** entries.length() = " << entries.length() << NL;
 
-    QString cont = "";
-
     bool dontcontinue = false;
 
     QSqlDatabase db = QSqlDatabase::database("contextmenu");
