@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -77,6 +77,13 @@ void PQMetaData::updateMetadata(QString path) {
     DBG << CURDATE << "PQMetaData::updateMetadata()" << NL
         << CURDATE << "** path = " << path.toStdString() << NL;
 
+    if(path == "") {
+        setValidFile(true);
+        setFileSize(0);
+        setEmptyExivData();
+        return;
+    }
+
     if(path.contains("::PQT::"))
         path = path.split("::PQT::").at(1);
     if(path.contains("::ARC::"))
