@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2022 Lukas Spies                                  **
+ ** Copyright (C) 2011-2023 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -433,7 +433,7 @@ bool PQValidate::validateImageFormatsDatabase() {
 
     queryInst.clear();
 
-    for(auto endings : toBeRemoved) {
+    for(const auto &endings : qAsConst(toBeRemoved)) {
 
         QSqlQuery query(dbinstalled);
         query.prepare("DELETE FROM imageformats WHERE endings=:endings");
@@ -548,6 +548,53 @@ bool PQValidate::validateSettingsDatabase() {
                     continue;
                 }
 
+                // new settings that are based on old settings
+                if(name == "PreviewColorIntensity") {
+
+                    // muted colors?
+                    bool muted = false;
+                    QSqlQuery qCheck(dbinstalled);
+                    if(!qCheck.exec("SELECT `value` FROM `openfile` WHERE `name`='PreviewMuted'")) {
+                        LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error checking PreviewMuted setting: " << qCheck.lastError().text().trimmed().toStdString() << NL;
+                        continue;
+                    }
+                    qCheck.next();
+                    muted = qCheck.value(0).toBool();
+
+                    // full colors?
+                    bool full = false;
+                    qCheck.clear();
+                    if(!qCheck.exec("SELECT `value` FROM `openfile` WHERE `name`='PreviewFullColors'")) {
+                        LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error checking PreviewFullColors setting: " << qCheck.lastError().text().trimmed().toStdString() << NL;
+                        continue;
+                    }
+                    qCheck.next();
+                    full = qCheck.value(0).toBool();
+                    qCheck.clear();
+
+                    if(full) {
+                        QSqlQuery queryupd(dbinstalled);
+                        if(!queryupd.exec("UPDATE `openfile` SET `value`=10 WHERE `name`='PreviewColorIntensity'")) {
+                            LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error updating PreviewColorIntensity setting with full colors: " << queryupd.lastError().text().trimmed().toStdString() << NL;
+                            continue;
+                        }
+                        queryupd.clear();
+                    } else if(muted) {
+                        QSqlQuery queryupd(dbinstalled);
+                        if(!queryupd.exec("UPDATE `openfile` SET `value`=3 WHERE `name`='PreviewColorIntensity'")) {
+                            LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error updating PreviewColorIntensity setting with muted colors: " << queryupd.lastError().text().trimmed().toStdString() << NL;
+                            continue;
+                        }
+                        queryupd.clear();
+                    }
+
+                    // delete old setting names
+                    QSqlQuery queryDel(dbinstalled);
+                    if(!queryDel.exec("DELETE FROM `openfile` WHERE `name`='PreviewMuted' OR `name`='PreviewFullColors'"))
+                        LOG << CURDATE << "PQValidate::validateSettingsDatabase(): Error deleting old settings PreviewMuted and PreviewFullColors: " << queryDel.lastError().text().trimmed().toStdString() << NL;
+                    queryDel.clear();
+                }
+
             // if entry does exist, make sure defaultvalue and datatype is valid
             } else {
 
@@ -595,6 +642,93 @@ bool PQValidate::validateShortcutsDatabase() {
         return false;
     }
 
+    /****************************************************/
+    // First update external table
+
+    QSqlQuery queryCol(dbinstalled);
+    if(!queryCol.exec("SELECT count() FROM PRAGMA_TABLE_INFO('external')")) {
+        LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error validating 'external' columns: " << queryCol.lastError().text().trimmed().toStdString() << NL;
+        queryCol.clear();
+        return false;
+    }
+
+    queryCol.next();
+    int c = queryCol.value(0).toInt();
+    queryCol.clear();
+
+    // If database needs to be migrated
+    if(c == 3) {
+
+        // backup old database
+        QFile f(ConfigFiles::SHORTCUTS_DB());
+        if(QFileInfo::exists(ConfigFiles::SHORTCUTS_DB() + ".bak"))
+            QFile::remove(ConfigFiles::SHORTCUTS_DB()+".bak");
+        if(!f.copy(ConfigFiles::SHORTCUTS_DB() + ".bak"))
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to backup old database, copying failed" << NL;
+
+        // add new column
+        if(!queryCol.exec("ALTER TABLE external ADD COLUMN arguments TEXT")) {
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Error adding 'arguments' columns to 'external' table: " << queryCol.lastError().text().trimmed().toStdString() << NL;
+            queryCol.clear();
+            return false;
+        }
+
+        // Loop over existing data and update with new format
+        queryCol.clear();
+
+        if(!queryCol.exec("SELECT command,shortcuts,close FROM external")) {
+            LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to migrate external shortcuts: " << queryCol.lastError().text().trimmed().toStdString() << NL;
+            queryCol.clear();
+            return false;
+        }
+
+        // save migrated data in list
+        QList<QStringList> lst;
+        while(queryCol.next()) {
+
+            QStringList oldexe = queryCol.value(0).toString().split(" ");
+            QString exec = oldexe.takeFirst();
+            QString args = oldexe.join(" ");
+
+            lst.append({exec, args, queryCol.value(1).toString(), queryCol.value(2).toString()});
+
+        }
+        queryCol.clear();
+
+        // if external shortcuts were set
+        if(lst.length() > 0) {
+
+            // delete old data
+            if(!queryCol.exec("DELETE FROM external")) {
+                LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to remove old external shortcuts to fill in migrated data: " << queryCol.lastError().text().trimmed().toStdString() << NL;
+                queryCol.clear();
+                return false;
+            }
+            queryCol.clear();
+
+            // insert migrated data
+            for(const auto &l : qAsConst(lst)) {
+
+                QSqlQuery queryNew(dbinstalled);
+                queryNew.prepare("INSERT INTO external (command, arguments, shortcuts, close) VALUES (:cmd, :arg, :sh, :cl)");
+                queryNew.bindValue(":cmd", l[0]);
+                queryNew.bindValue(":arg", l[1]);
+                queryNew.bindValue(":sh", l[2]);
+                queryNew.bindValue(":cl", l[3]);
+                if(!queryNew.exec()) {
+                    LOG << CURDATE << "PQValidate::validateShortcutsDatabase(): Unable to insert migrated data, old data might be lost: " << queryNew.lastError().text().trimmed().toStdString() << NL;
+                    queryNew.clear();
+                    return false;
+                }
+            }
+
+        }
+
+    }
+
+    /****************************************************/
+    // Validate with default data
+
     // open database
     QFile::remove(ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
     QFile::copy(":/shortcuts.db", ConfigFiles::CACHE_DIR()+"/photoqt_tmp.db");
